// Navigation.tsx
'use client';

import { useState, useEffect } from 'react';
import Link from 'next/link';
import { usePathname } from 'next/navigation';
import { Menu, X, ExternalLink } from 'lucide-react';
import { ThemeToggle } from './ThemeToggle';
import { internalLinks, headerLinks } from '@/data/navigation';

export function Navigation() {
  const [isMenuOpen, setIsMenuOpen] = useState(false);
  const pathname = usePathname();

  useEffect(() => {
    const handleClickOutside = (event: MouseEvent) => {
      const target = event.target as HTMLElement;
      if (!target.closest('.menu-toggle') && !target.closest('.nav-content') && isMenuOpen) {
        setIsMenuOpen(false);
      }
    };

    document.addEventListener('click', handleClickOutside);
    return () => document.removeEventListener('click', handleClickOutside);
  }, [isMenuOpen]);

  // Close menu when route changes
  useEffect(() => {
    setIsMenuOpen(false);
  }, [pathname]);

  const toggleMenu = () => {
    setIsMenuOpen(!isMenuOpen);
  };

  return (
    <nav aria-label="Main navigation">
      <div className="container">
        <Link href="/" className={`logo ${pathname === '/' ? 'active' : ''}`}>
          ./charlotte.sh
        </Link>

        <button
          className="menu-toggle"
          aria-expanded={isMenuOpen}
          aria-controls="navigation-menu"
          aria-label="Toggle menu"
          onClick={toggleMenu}
        >
          {isMenuOpen ? <X size={24} /> : <Menu size={24} />}
        </button>

        <div className={`nav-content ${isMenuOpen ? 'menu-open' : ''}`} id="navigation-menu">
          {/* Internal Navigation Links (Left) */}
          <ul className="nav-links-internal">
            {internalLinks.map((link) => (
              <li key={link.name}>
                <Link 
                  href={link.href}
                  className={pathname === link.href ? 'active' : ''}
                >
                  {link.name}
                </Link>
              </li>
            ))}
          </ul>

          {/* External Social Links (Right) */}
          <ul className="nav-links-external">
            {headerLinks.map((link) => (
              <li key={link.name}>
                <a href={link.url} target="_blank" rel="noopener noreferrer">
                  {link.name}
                  <ExternalLink className="icon-small" />
                  <span className="visually-hidden">(opens in new tab)</span>
                </a>
              </li>
            ))}
            <li>
              <ThemeToggle />
            </li>
          </ul>
        </div>
      </div>
    </nav>
  );
}